==> FlightGear-0.7.3.tar.gz: FlightGear-0.7.3/src/FDM/JSBsim/FGControls.cpp <==
// controls.cxx -- defines a standard interface to all flight sim controls
//
// Written by Curtis Olson, started May 1997.
//
// Copyright (C) 1997  Curtis L. Olson  - curt@infoplane.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// $Id: FGControls.cpp,v 1.10 2000/05/16 19:35:11 curt Exp $
// (Log is kept at end of this file)


#include "FGControls.h"


FGControls controls;


// Constructor
FGControls::FGControls() :
    aileron( 0.0 ),
    elevator( 0.0 ),
    elevator_trim( 1.969572E-03 ),
    rudder( 0.0 )
{
  for ( int engine = 0; engine < MAX_ENGINES; engine++ ) {
    throttle[engine] = 0.0;
  }

  for ( int wheel = 0; wheel < MAX_WHEELS; wheel++ ) {
    brake[wheel] = 0.0;
  }
}


// Destructor
FGControls::~FGControls() {
}


// $Log: FGControls.cpp,v $
// Revision 1.10  2000/05/16 19:35:11  curt
// Updates from the Jon and Tony show.
//
// Tony submitted:
//
// JSBsim:
// Added trimming routine, it is longitudinal & in-air only at this point
// Added support for taking wind & weather data from external source
// Added support for flaps.
// Added independently settable pitch trim
// Added alphamin and max to config file, stall modeling and warning to
// follow
//
// c172.cfg:
// Flaps!
// Adjusted Cmo, model should be speed stable now
//
// FG:
// Hooked up Christian's weather code, should be using it soon.
// Hooked up the trimming routine.  Note that the X-15 will not trim.
//   This is not a model or trimming routine deficiency, just the
//   nature of the X-15
// The trimming routine sets the pitch trim and and throttle at startup.
// The throttle is set using Norman's code for the autothrottle so the
// autothrottle is on by default.  --notrim will turn it off.
// Added --vc, --mach, and --notrim switches
//       (vc is airspeed in knots)
// uBody, vBody, and wBody are still supported, last one entered
// on the command line counts, i.e. you can set vc or mach or u,v,
// and w but any combination will be ignored.
//
// Revision 1.3  2000/04/26 10:55:57  jsb
// Made changes as required by Curt to install JSBSim into FGFS
//
// Revision 1.8  2000/04/24 21:49:06  curt
// Updated JSBsim code.
//
// Revision 1.2  2000/04/15 13:16:54  jsb
// In good shape, now, changes to Coefficient and aircraft, mostly, with new commands added and inputs and outputs separated.
//
// Revision 1.7  1999/12/30 17:01:59  curt
// Here is a wrap-up of the latest changes to JSBSim. It still is flaky, but
// much less so due to returning the aero reference point stuff to the config
// files. Don't know what happened there ...
//
// Additionally, I have added a new field to the config file: CFG_VERSION. A
// version number, currently 1.1, is assigned to the config file and a matching
// definition is found in FGDefs.h. The two need to match. Tony has also added
// code into FGAircraft.cpp to handle if aero reference point is not specified.
//
// Revision 1.6  1999/09/07 21:15:45  curt
// Updates to get engine working.
//
// Revision 1.1  1999/02/13 01:12:03  curt
// Initial Revision.
//
// Revision 1.1  1999/02/09 04:51:32  jon
// Initial revision
//
// Revision 1.3  1998/12/05 16:13:12  curt
// Renamed class fgCONTROLS to class FGControls.
//
// Revision 1.2  1998/10/25 14:08:41  curt
// Turned "struct fgCONTROLS" into a class, with inlined accessor functions.
//
// Revision 1.1  1998/10/18 01:51:05  curt
// c++-ifying ...
//
// Revision 1.8  1998/09/29 02:01:31  curt
// Added a brake.
//
// Revision 1.7  1998/02/07 15:29:36  curt
// Incorporated HUD changes and struct/typedef changes from Charlie Hotchkiss
// <chotchkiss@namg.us.anritsu.com>
//
// Revision 1.6  1998/01/19 19:27:02  curt
// Merged in make system changes from Bob Kuehne <rpk@sgi.com>
// This should simplify things tremendously.
//
// Revision 1.5  1998/01/19 18:40:22  curt
// Tons of little changes to clean up the code and to remove fatal errors
// when building with the c++ compiler.
//
// Revision 1.4  1997/12/10 22:37:41  curt
// Prepended "fg" on the name of all global structures that didn't have it yet.
// i.e. "struct WEATHER {}" became "struct fgWEATHER {}"
//
// Revision 1.3  1997/08/27 03:30:01  curt
// Changed naming scheme of basic shared structures.
//
// Revision 1.2  1997/06/21 17:12:48  curt
// Capitalized subdirectory names.
//
// Revision 1.1  1997/05/31 19:24:04  curt
// Initial revision.
//

==> FlightGear-0.7.4.tar.gz: FlightGear-0.7.4/src/FDM/JSBsim/FGControls.cpp <==
// controls.cxx -- defines a standard interface to all flight sim controls
//
// Written by Curtis Olson, started May 1997.
//
// Copyright (C) 1997  Curtis L. Olson  - curt@infoplane.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// $Id: FGControls.cpp,v 1.13 2000/07/06 19:02:46 curt Exp $
// (Log is kept at end of this file)


#include "FGControls.h"


FGControls controls;


// Constructor
FGControls::FGControls() :
    aileron( 0.0 ),
    elevator( 0.0 ),
    elevator_trim( 1.969572E-03 ),
    rudder( 0.0 )
{
  for ( int engine = 0; engine < MAX_ENGINES; engine++ ) {
    throttle[engine] = 0.0;
  }

  for ( int wheel = 0; wheel < MAX_WHEELS; wheel++ ) {
    brake[wheel] = 0.0;
  }
}


// Destructor
FGControls::~FGControls() {
}


// $Log: FGControls.cpp,v $
// Revision 1.13  2000/07/06 19:02:46  curt
// Updates from Jon's official CVS tree.
//
// Revision 1.3  2000/04/26 10:55:57  jsb
// Made changes as required by Curt to install JSBSim into FGFS
//
// Revision 1.8  2000/04/24 21:49:06  curt
// Updated JSBsim code.
//
// Revision 1.2  2000/04/15 13:16:54  jsb
// In good shape, now, changes to Coefficient and aircraft, mostly, with new commands added and inputs and outputs separated.
//
// Revision 1.7  1999/12/30 17:01:59  curt
// Here is a wrap-up of the latest changes to JSBSim. It still is flaky, but
// much less so due to returning the aero reference point stuff to the config
// files. Don't know what happened there ...
//
// Additionally, I have added a new field to the config file: CFG_VERSION. A
// version number, currently 1.1, is assigned to the config file and a matching
// definition is found in FGDefs.h. The two need to match. Tony has also added
// code into FGAircraft.cpp to handle if aero reference point is not specified.
//
// Revision 1.6  1999/09/07 21:15:45  curt
// Updates to get engine working.
//
// Revision 1.1  1999/02/13 01:12:03  curt
// Initial Revision.
//
// Revision 1.1  1999/02/09 04:51:32  jon
// Initial revision
//
// Revision 1.3  1998/12/05 16:13:12  curt
// Renamed class fgCONTROLS to class FGControls.
//
// Revision 1.2  1998/10/25 14:08:41  curt
// Turned "struct fgCONTROLS" into a class, with inlined accessor functions.
//
// Revision 1.1  1998/10/18 01:51:05  curt
// c++-ifying ...
//
// Revision 1.8  1998/09/29 02:01:31  curt
// Added a brake.
//
// Revision 1.7  1998/02/07 15:29:36  curt
// Incorporated HUD changes and struct/typedef changes from Charlie Hotchkiss
// <chotchkiss@namg.us.anritsu.com>
//
// Revision 1.6  1998/01/19 19:27:02  curt
// Merged in make system changes from Bob Kuehne <rpk@sgi.com>
// This should simplify things tremendously.
//
// Revision 1.5  1998/01/19 18:40:22  curt
// Tons of little changes to clean up the code and to remove fatal errors
// when building with the c++ compiler.
//
// Revision 1.4  1997/12/10 22:37:41  curt
// Prepended "fg" on the name of all global structures that didn't have it yet.
// i.e. "struct WEATHER {}" became "struct fgWEATHER {}"
//
// Revision 1.3  1997/08/27 03:30:01  curt
// Changed naming scheme of basic shared structures.
//
// Revision 1.2  1997/06/21 17:12:48  curt
// Capitalized subdirectory names.
//
// Revision 1.1  1997/05/31 19:24:04  curt
// Initial revision.
//
